package com.shzg.project.worn.mapper;

import java.util.List;
import com.shzg.project.worn.domain.WornTechnicalAppraisalFile;

/**
 * 技术鉴定附件Mapper接口
 * 
 * @author shzg
 * @date 2026-04-10
 */
public interface WornTechnicalAppraisalFileMapper 
{
    /**
     * 查询技术鉴定附件
     * 
     * @param id 技术鉴定附件主键
     * @return 技术鉴定附件
     */
    public WornTechnicalAppraisalFile selectWornTechnicalAppraisalFileById(Long id);

    /**
     * 查询技术鉴定附件列表
     * 
     * @param wornTechnicalAppraisalFile 技术鉴定附件
     * @return 技术鉴定附件集合
     */
    public List<WornTechnicalAppraisalFile> selectWornTechnicalAppraisalFileList(WornTechnicalAppraisalFile wornTechnicalAppraisalFile);

    /**
     * 新增技术鉴定附件
     * 
     * @param wornTechnicalAppraisalFile 技术鉴定附件
     * @return 结果
     */
    public int insertWornTechnicalAppraisalFile(WornTechnicalAppraisalFile wornTechnicalAppraisalFile);

    /**
     * 修改技术鉴定附件
     * 
     * @param wornTechnicalAppraisalFile 技术鉴定附件
     * @return 结果
     */
    public int updateWornTechnicalAppraisalFile(WornTechnicalAppraisalFile wornTechnicalAppraisalFile);

    /**
     * 删除技术鉴定附件
     * 
     * @param id 技术鉴定附件主键
     * @return 结果
     */
    public int deleteWornTechnicalAppraisalFileById(Long id);
    int removeWornTechnicalAppraisalFileById(WornTechnicalAppraisalFile wornTechnicalAppraisalFile);

    /**
     * 批量删除技术鉴定附件
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWornTechnicalAppraisalFileByIds(Long[] ids);
    /**
     * 根据技术鉴定表ID查询附件列表
     *
     * @param appraisalId 技术鉴定表ID
     * @return 附件列表
     */
    List<WornTechnicalAppraisalFile> selectWornTechnicalAppraisalFileByAppraisalId(Long appraisalId);
}
